# biscuit
A WSGI compliant web framework for [insert something cool here].

### Getting Started
Currently there are only a few aspects to be aware of.

Firstly, install the requirements:
```
pip install -r requirements.txt
```

Next you can run the tests via `pytest`

Finally, to start the example project run gunicorn like so:
```
gunicorn examples.basic_app:APP
```

#### How to contribute
Idk yet, just open some PRs dude
